package com.ynet.life.controller;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.session.Session;
import com.ynet.gene.web.servlet.ModelAndView;
import com.ynet.gene.web.servlet.mvc.GENEFlowExecuteResult;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.file.download.FileAccessValidator;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/* loaded from: com_ynet_life_controller.jar:com/ynet/life/controller/LifeDownloadController.class */
public class LifeDownloadController extends LifeRequestController {
    private FileAccessValidator validator = null;

    /* JADX WARN: Finally extract failed */
    @Override // com.ynet.life.controller.LifeRequestController
    public ModelAndView doRequest(HttpServletRequest request, HttpServletResponse response) throws Exception {
        if (this.openMonitor) {
            this.accessInfo.newAccess();
        }
        if (this.inputView == null) {
            Session session = doSessionCheck(request, response);
            Context sessionContext = null;
            if (session != null) {
                sessionContext = (Context) session.getAttribute(GENEConstance.ATTR_CONTEXT);
            }
            GENEFlowExecuteResult result = executeGENELogic(sessionContext, request, response);
            if (result.e != null) {
                Trace.logError(GENEConstance.GENE_MVC, result.e.getMessage(), result.e);
                throw new GENEException(result.e);
            }
            Context context = result.context;
            try {
                String filePathName = (String) result.context.getDataValue("downloadFile");
                request.getSession(false).getServletContext().getRealPath("/download");
                File downloadFile = new File(filePathName);
                if (!downloadFile.exists()) {
                    Trace.logError(GENEConstance.GENE_MVC, "文件[" + filePathName + "]不存在");
                    throw LifeConstants.EXCEPTION_FILE_NOT_FOUND;
                }
                getValidator().validate(filePathName, sessionContext);
                FileInputStream inToUser = null;
                ServletOutputStream outToUser = null;
                try {
                    try {
                        inToUser = new FileInputStream(downloadFile);
                        response.setHeader("Content-disposition", "attachment; filename=" + downloadFile.getName());
                        response.setHeader("Content-Length", String.valueOf(downloadFile.length()));
                        ServletOutputStream outputStream = response.getOutputStream();
                        outToUser = outputStream;
                        outputStream.flush();
                        while (true) {
                            int aRead = inToUser.read();
                            if (aRead == -1) {
                                break;
                            }
                            outToUser.write(aRead);
                        }
                        outToUser.flush();
                        try {
                            inToUser.close();
                            if (outToUser != null) {
                                outToUser.close();
                            }
                        } catch (IOException unused) {
                            Trace.logWarning(GENEConstance.GENE_MVC, "文件对象关闭异常");
                        }
                    } catch (IOException ex) {
                        Trace.logError(GENEConstance.GENE_MVC, "文件下载异常", ex);
                        if (inToUser != null) {
                            try {
                                inToUser.close();
                            } catch (IOException unused2) {
                                Trace.logWarning(GENEConstance.GENE_MVC, "文件对象关闭异常");
                            }
                        }
                        if (outToUser != null) {
                            outToUser.close();
                        }
                    }
                    context.terminate();
                    return null;
                } catch (Throwable th) {
                    if (inToUser != null) {
                        try {
                            inToUser.close();
                        } catch (IOException unused3) {
                            Trace.logWarning(GENEConstance.GENE_MVC, "文件对象关闭异常");
                            throw th;
                        }
                    }
                    if (outToUser != null) {
                        outToUser.close();
                    }
                    throw th;
                }
            } catch (Throwable th2) {
                context.terminate();
                throw th2;
            }
        }
        return null;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v0 */
    /* JADX WARN: Type inference failed for: r0v1, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v3, types: [com.ynet.life.file.download.FileAccessValidator] */
    /* JADX WARN: Type inference failed for: r0v8, types: [com.ynet.life.controller.LifeDownloadController] */
    public FileAccessValidator getValidator() throws GENEException {
        ?? r0 = this;
        synchronized (r0) {
            r0 = this.validator;
            if (r0 == 0) {
                try {
                    String selfDefineSettingsValue = LifeStandard.getSelfDefineSettingsValue("downloadValidatorClass");
                    String validatorClass = selfDefineSettingsValue;
                    if (selfDefineSettingsValue == null) {
                        validatorClass = "com.ynet.life.file.download.DefaultFileAccessValidator";
                    }
                    r0 = this;
                    r0.validator = (FileAccessValidator) Class.forName(validatorClass).newInstance();
                } catch (Exception e) {
                    Trace.logError("LifeFile", "instantiate download file validator failed.", e);
                    throw new GENEException("instantiate download file validator failed.", e);
                }
            }
        }
        return this.validator;
    }
}
